% Function to reduce two timeseries to the time they both cover
% gives back two reduced TS
% example: [tsint1,tsint2] = adjusttimeseries(ts1,ts2)
% !!expects same periods!!
%
%
% written 2007 by D. Maraun and J. Laehnemann
%

function [tsint1,tsint2] = adjusttimeseries(ts1,ts2);

  % CHECK TIME SERIES INPUT 

  
  if (size(ts1,2)==2)
    y1 = ts1(:,2)';
    t1 = ts1(:,1)';
    dt1= (ts1(length(y1),1)-ts1(1,1))/(length(y1)-1);
  end;  
  if (size(ts1,2)==1)
    y1 = ts1;
    dt1 = (ts1(length(y1),1)-ts1(1,1))/(length(y1)-1);
    t1 = (1:dt1:length(y1));
  end;
  if (size(ts1,2)>2)
    error('please provide two column matrix for time series 1');end;
  
  if (size(ts2,2)==2)
    y2 = ts2(:,2)';
    t2 = ts2(:,1)';
    dt2= (ts2(length(y2),1)-ts2(1,1))/(length(y2)-1);
  end;  
  if (size(ts2,2)==1)
    y2 = ts2;
    dt2 = (ts2(length(y2),1)-ts2(1,1))/(length(y2)-1);
    t2 = (1:dt2:length(y2));
  end;
  if (size(ts2,2)>2)
    error('please provide two column matrix for time series 2');end;

  if (abs(dt1-dt2)>0.0001)
    error('dt1 not equal dt2');
  else
    dt=dt1;
  end;

  start1=t1(1); % starting times of TS
  start2=t2(1);
    
  last1=t1(length(t1)); % ending time of TS
  last2=t2(length(t2));
    
  start=max(start1,start2); % start of overlap period
  last=min(last1,last2); % end of overlap period
  toverlap=(start:dt:last)';
    
  int1=(start<=t1&t1<=last); % reduce first time vector to overlap period, other values to 0
  int2=(start<=t2&t2<=last); % reduce second time vector to overlap period, other values to 0
  
  tsint1=[toverlap y1(int1~=0)']; % create new TS with only the overlap period 
  tsint2=[toverlap y2(int2~=0)']; % i.e. starting at start and covering period where int1/int2 not 0

end
