%
% CHECK AREAL SIGNIFICANCE LEVEL
% ---------------------------------
%
% This function checks if desired Areal Significance Levels agree with
% supported values. It is called by wsp.m and wco.m
%
%
% written by D. Maraun and J. Laehnemann
%



function [siglevel,arealsiglevel] = checkarealsiglevel(sw,tw,w0,arealsiglevel,siglevel,type);

  if (type==0) % used in WSP
    
    swv = [0 0.5 1];
    twv = [0 1.5 3];
    w0v = [pi 2*pi];
    
    if (length(swv(swv==sw))==0 | length(twv(twv==tw))==0 | length(w0v(w0v==w0))==0)
      arealsiglevel = 0;
      Message_checkarealsiglevel = strvcat('# areawise test for spectrum currently', '# only possible for', '# sw in (0,0.5,1)','tw in (0,1.5,3)', '# w0 in (pi,2pi)', '# No areawise test performed')
    end;
  end;
  
  if (type==1) % used in WCO

    swv = 0.5;
    twv = 1.5;
    w0v = 2*pi;

    if (length(swv(swv==sw))==0 | length(twv(twv==tw))==0 | length(w0v(w0v==w0))==0)
      arealsiglevel = 0;
      Message_checkarealsiglevel = strvcat('# areawise test for coherence currently', '# only possible for', '# sw = 0.5', '# tw = 1.5', '# w0 = 2pi', '# No areawise test performed') 
    end;
  end;

  
  if (arealsiglevel~=0)
    arealsiglevel = 0.9;
    siglevel = 0.95;
    Message_checkarealsiglevel = ('# currently only siglevel=0.95 and arealsiglevel=0.9 possible for areawise test')
  end;
  
end
